# v0.0.1 (31-08-2011)

First version
First test written 29-08-2011

Changes:

- Custom HTTP headers
- Request data/params
- Multiple file uploading
- Cookies support (dict or CookieJar)
- Redirection history
- Proxy support (http, https, socks4/5)
- Custom interface for request!
- Auto decompression of GZipped content
- Unicode URL support
- Request timers and another info
- Certificate validation
- ipv6 support